@@ -1,5 +1,4 @@
 <?php
-
 namespace PhpAmqpLib\Channel;
 
 use PhpAmqpLib\Exception\AMQPBasicCancelException;
@@ -12,37 +11,22 @@ use PhpAmqpLib\Wire\AMQPWriter;
 
 class AMQPChannel extends AbstractChannel
 {
-
-    /**
-     * @var array
-     */
+    /** @var array */
     public $callbacks = array();
 
-    /**
-     * Whether or not the channel has been "opened" or not
-     *
-     * @var bool
-     */
+    /** @var bool Whether or not the channel has been "opened" or not */
     protected $is_open = false;
 
-    /**
-     * @var int
-     */
+    /** @var int */
     protected $default_ticket;
 
-    /**
-     * @var bool
-     */
+    /** @var bool */
     protected $active;
 
-    /**
-     * @var array
-     */
+    /** @var array */
     protected $alerts;
 
-    /**
-     * @var bool
-     */
+    /** @var bool */
     protected $auto_decode;
 
     /**
@@ -55,14 +39,9 @@ class AMQPChannel extends AbstractChannel
      *
      * @var callable
      */
-    protected $basic_return_callback = null;
+    protected $basic_return_callback;
 
-    /**
-     *
-     * @var array
-     * used to keep track of the messages that are going
-     * to be batch published.
-     */
+    /** @var array Used to keep track of the messages that are going to be batch published. */
     protected $batch_messages = array();
 
     /**
@@ -73,24 +52,19 @@ class AMQPChannel extends AbstractChannel
      */
     private $published_messages = array();
 
-    /**
-     * @var int
-     */
+    /** @var int */
     private $next_delivery_tag = 0;
 
-    /**
-     * @var callable
-     */
-    private $ack_handler = null;
+    /** @var callable */
+    private $ack_handler;
 
-    /**
-     * @var callable
-     */
-    private $nack_handler = null;
+    /** @var callable */
+    private $nack_handler;
 
     /**
      * Circular buffer to speed up both basic_publish() and publish_batch().
      * Max size limited by $publish_cache_max_size.
+     *
      * @var array
      * @see basic_publish()
      * @see publish_batch()
@@ -98,12 +72,18 @@ class AMQPChannel extends AbstractChannel
     private $publish_cache;
 
     /**
-     * Maximal size of $publish_cache.
+     * Maximal size of $publish_cache
+     *
      * @var int
      */
     private $publish_cache_max_size;
 
-
+    /**
+     * @param \PhpAmqpLib\Connection\AbstractConnection $connection
+     * @param null $channel_id
+     * @param bool $auto_decode
+     * @throws \Exception
+     */
     public function __construct($connection, $channel_id = null, $auto_decode = true)
     {
         if ($channel_id == null) {
@@ -116,7 +96,7 @@ class AMQPChannel extends AbstractChannel
         $this->publish_cache_max_size = 100;
 
         if ($this->debug) {
-            MiscHelper::debug_msg("using channel_id: " . $channel_id);
+            MiscHelper::debug_msg('using channel_id: ' . $channel_id);
         }
 
         $this->default_ticket = 0;
@@ -134,15 +114,6 @@ class AMQPChannel extends AbstractChannel
         }
     }
 
-
-
-    public function __destruct()
-    {
-        $this->close();
-    }
-
-
-
     /**
      * Tear down this object, after we've agreed to close with the server.
      */
@@ -155,8 +126,6 @@ class AMQPChannel extends AbstractChannel
         $this->is_open = false;
     }
 
-
-
     /**
      * Only for AMQP0.8.0
      * This method allows the server to send a non-fatal warning to
@@ -173,22 +142,24 @@ class AMQPChannel extends AbstractChannel
         $reply_code = $args->read_short();
         $reply_text = $args->read_shortstr();
         $details = $args->read_table();
-
         array_push($this->alerts, array($reply_code, $reply_text, $details));
     }
 
-
-
     /**
-     * request a channel close
+     * Request a channel close
+     *
+     * @param int $reply_code
+     * @param string $reply_text
+     * @param array $method_sig
+     * @return mixed
      */
-    public function close($reply_code = 0, $reply_text = "", $method_sig = array(0, 0))
+    public function close($reply_code = 0, $reply_text = '', $method_sig = array(0, 0))
     {
         if ($this->is_open !== true || null === $this->connection) {
             $this->do_close();
+
             return; // already closed
         }
-
         list($class_id, $method_id, $args) = $this->protocolWriter->channelClose(
             $reply_code,
             $reply_text,
@@ -203,8 +174,6 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
      * @param AMQPReader $args
      * @throws \PhpAmqpLib\Exception\AMQPProtocolChannelException
@@ -222,10 +191,10 @@ class AMQPChannel extends AbstractChannel
         throw new AMQPProtocolChannelException($reply_code, $reply_text, array($class_id, $method_id));
     }
 
-
-
     /**
-     * confirm a channel close
+     * Confirm a channel close
+     * Alias of AMQPChannel::do_close()
+     *
      * @param AMQPReader $args
      */
     protected function channel_close_ok($args)
@@ -233,10 +202,8 @@ class AMQPChannel extends AbstractChannel
         $this->do_close();
     }
 
-
-
     /**
-     * enable/disable flow from peer
+     * Enables/disables flow from peer
      *
      * @param $active
      * @return mixed
@@ -251,8 +218,6 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
      * @param AMQPReader $args
      */
@@ -262,16 +227,15 @@ class AMQPChannel extends AbstractChannel
         $this->x_flow_ok($this->active);
     }
 
-
-
+    /**
+     * @param $active
+     */
     protected function x_flow_ok($active)
     {
         list($class_id, $method_id, $args) = $this->protocolWriter->channelFlow($active);
         $this->send_method_frame(array($class_id, $method_id), $args);
     }
 
-
-
     /**
      * @param AMQPReader $args
      * @return bool
@@ -281,16 +245,14 @@ class AMQPChannel extends AbstractChannel
         return $args->read_bit();
     }
 
-
-
     /**
      * @param string $out_of_band
      * @return mixed
      */
-    protected function x_open($out_of_band = "")
+    protected function x_open($out_of_band = '')
     {
         if ($this->is_open) {
-            return NULL;
+            return null;
         }
 
         list($class_id, $method_id, $args) = $this->protocolWriter->channelOpen($out_of_band);
@@ -301,23 +263,21 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
      * @param AMQPReader $args
      */
     protected function channel_open_ok($args)
     {
         $this->is_open = true;
+
         if ($this->debug) {
-            MiscHelper::debug_msg("Channel open");
+            MiscHelper::debug_msg('Channel open');
         }
     }
 
-
-
     /**
-     * request an access ticket
+     * Requests an access ticket
+     *
      * @param string $realm
      * @param bool $exclusive
      * @param bool $passive
@@ -350,10 +310,9 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * grant access to server resources
+     * Grants access to server resources
+     *
      * @param AMQPReader $args
      * @return string
      */
@@ -364,10 +323,9 @@ class AMQPChannel extends AbstractChannel
         return $this->default_ticket;
     }
 
-
-
     /**
-     * declare exchange, create if needed
+     * Declares exchange
+     *
      * @param string $exchange
      * @param string $type
      * @param bool $passive
@@ -375,9 +333,7 @@ class AMQPChannel extends AbstractChannel
      * @param bool $auto_delete
      * @param bool $internal
      * @param bool $nowait
-     * @param null $arguments
-     * @param null $ticket
-     * @return mixed
+     * @return mixed|null
      */
     public function exchange_declare(
         $exchange,
@@ -390,7 +346,6 @@ class AMQPChannel extends AbstractChannel
         $arguments = null,
         $ticket = null
     ) {
-
         $arguments = $this->getArguments($arguments);
         $ticket = $this->getTicket($ticket);
 
@@ -409,7 +364,7 @@ class AMQPChannel extends AbstractChannel
         $this->send_method_frame(array($class_id, $method_id), $args);
 
         if ($nowait) {
-            return NULL;
+            return null;
         }
 
         return $this->wait(array(
@@ -417,26 +372,21 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirms an exchange declaration
-     *
-     * @param AMQPReader $args
+     * Confirms an exchange declaration
      */
     protected function exchange_declare_ok($args)
     {
     }
 
-
-
     /**
-     * delete an exchange
+     * Deletes an exchange
+     *
      * @param string $exchange
      * @param bool $if_unused
      * @param bool $nowait
      * @param null $ticket
-     * @return mixed
+     * @return mixed|null
      */
     public function exchange_delete(
         $exchange,
@@ -463,33 +413,28 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm deletion of an exchange
-     *
-     * @param AMQPReader $args
+     * Confirms deletion of an exchange
      */
     protected function exchange_delete_ok($args)
     {
     }
 
-
-
     /**
-     * bind dest exchange to source exchange
+     * Binds dest exchange to source exchange
+     *
      * @param string $destination
      * @param string $source
      * @param string $routing_key
      * @param bool $nowait
      * @param null $arguments
      * @param null $ticket
-     * @return mixed
+     * @return mixed|null
      */
     public function exchange_bind(
         $destination,
         $source,
-        $routing_key = "",
+        $routing_key = '',
         $nowait = false,
         $arguments = null,
         $ticket = null
@@ -517,21 +462,16 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm bind successful
-     *
-     * @param AMQPReader $args
+     * Confirms bind successful
      */
     protected function exchange_bind_ok($args)
     {
     }
 
-
-
     /**
-     * unbind dest exchange from source exchange
+     * Unbinds dest exchange from source exchange
+     *
      * @param string $destination
      * @param string $source
      * @param string $routing_key
@@ -539,7 +479,7 @@ class AMQPChannel extends AbstractChannel
      * @param null $ticket
      * @return mixed
      */
-    public function exchange_unbind($destination, $source, $routing_key = "", $arguments = null, $ticket = null)
+    public function exchange_unbind($destination, $source, $routing_key = '', $arguments = null, $ticket = null)
     {
         $arguments = $this->getArguments($arguments);
         $ticket = $this->getTicket($ticket);
@@ -559,30 +499,25 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm unbind successful
-     *
-     * @param AMQPReader $args
+     * Confirms unbind successful
      */
     protected function exchange_unbind_ok($args)
     {
     }
 
-
-
     /**
-     * bind queue to an exchange
+     * Binds queue to an exchange
+     *
      * @param string $queue
      * @param string $exchange
      * @param string $routing_key
      * @param bool $nowait
      * @param null $arguments
      * @param null $ticket
-     * @return mixed
+     * @return mixed|null
      */
-    public function queue_bind($queue, $exchange, $routing_key = "", $nowait = false, $arguments = null, $ticket = null)
+    public function queue_bind($queue, $exchange, $routing_key = '', $nowait = false, $arguments = null, $ticket = null)
     {
         $arguments = $this->getArguments($arguments);
         $ticket = $this->getTicket($ticket);
@@ -607,21 +542,16 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm bind successful
-     *
-     * @param AMQPReader $args
+     * Confirms bind successful
      */
     protected function queue_bind_ok($args)
     {
     }
 
-
-
     /**
-     * unbind queue from an exchange
+     * Unbind queue from an exchange
+     *
      * @param string $queue
      * @param string $exchange
      * @param string $routing_key
@@ -629,7 +559,7 @@ class AMQPChannel extends AbstractChannel
      * @param null $ticket
      * @return mixed
      */
-    public function queue_unbind($queue, $exchange, $routing_key = "", $arguments = null, $ticket = null)
+    public function queue_unbind($queue, $exchange, $routing_key = '', $arguments = null, $ticket = null)
     {
         $arguments = $this->getArguments($arguments);
         $ticket = $this->getTicket($ticket);
@@ -649,33 +579,28 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm unbind successful
-     *
-     * @param AMQPReader $args
+     * Confirms unbind successful
      */
     protected function queue_unbind_ok($args)
     {
     }
 
-
-
     /**
-     * declare queue, create if needed
+     * Declares queue, creates if needed
+     *
      * @param string $queue
      * @param bool $passive
      * @param bool $durable
      * @param bool $exclusive
      * @param bool $auto_delete
      * @param bool $nowait
-     * @param array $arguments
-     * @param int $ticket
-     * @return mixed
+     * @param null $arguments
+     * @param null $ticket
+     * @return mixed|null
      */
     public function queue_declare(
-        $queue = "",
+        $queue = '',
         $passive = false,
         $durable = false,
         $exclusive = false,
@@ -709,10 +634,8 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirms a queue definition
+     * Confirms a queue definition
      *
      * @param AMQPReader $args
      * @return array
@@ -726,12 +649,17 @@ class AMQPChannel extends AbstractChannel
         return array($queue, $message_count, $consumer_count);
     }
 
-
-
     /**
-     * delete a queue
+     * Deletes a queue
+     *
+     * @param string $queue
+     * @param bool $if_unused
+     * @param bool $if_empty
+     * @param bool $nowait
+     * @param null $ticket
+     * @return mixed|null
      */
-    public function queue_delete($queue = "", $if_unused = false, $if_empty = false, $nowait = false, $ticket = null)
+    public function queue_delete($queue = '', $if_unused = false, $if_empty = false, $nowait = false, $ticket = null)
     {
         $ticket = $this->getTicket($ticket);
 
@@ -754,10 +682,8 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm deletion of a queue
+     * Confirms deletion of a queue
      *
      * @param AMQPReader $args
      * @return string
@@ -767,16 +693,15 @@ class AMQPChannel extends AbstractChannel
         return $args->read_long();
     }
 
-
-
     /**
-     * purge a queue
+     * Purges a queue
+     *
      * @param string $queue
      * @param bool $nowait
      * @param null $ticket
-     * @return mixed
+     * @return mixed|null
      */
-    public function queue_purge($queue = "", $nowait = false, $ticket = null)
+    public function queue_purge($queue = '', $nowait = false, $ticket = null)
     {
         $ticket = $this->getTicket($ticket);
         list($class_id, $method_id, $args) = $this->protocolWriter->queuePurge($ticket, $queue, $nowait);
@@ -792,10 +717,8 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirms a queue purge
+     * Confirms a queue purge
      *
      * @param AMQPReader $args
      * @return string
@@ -805,10 +728,11 @@ class AMQPChannel extends AbstractChannel
         return $args->read_long();
     }
 
-
-
     /**
-     * acknowledge one or more messages
+     * Acknowledges one or more messages
+     *
+     * @param string $delivery_tag
+     * @param bool $multiple
      */
     public function basic_ack($delivery_tag, $multiple = false)
     {
@@ -816,8 +740,6 @@ class AMQPChannel extends AbstractChannel
         $this->send_method_frame(array($class_id, $method_id), $args);
     }
 
-
-
     /**
      * Called when the server sends a basic.ack
      *
@@ -831,17 +753,14 @@ class AMQPChannel extends AbstractChannel
 
         if (false === isset($this->published_messages[$delivery_tag])) {
             throw new AMQPRuntimeException(sprintf(
-                    'Server ack\'ed unknown delivery_tag %s',
-                    $delivery_tag
-                )
-            );
+                'Server ack\'ed unknown delivery_tag %s',
+                $delivery_tag
+            ));
         }
 
         $this->internal_ack_handler($delivery_tag, $multiple, $this->ack_handler);
     }
 
-
-
     /**
      * Called when the server sends a basic.nack
      *
@@ -855,22 +774,19 @@ class AMQPChannel extends AbstractChannel
 
         if (false === isset($this->published_messages[$delivery_tag])) {
             throw new AMQPRuntimeException(sprintf(
-                    'Server nack\'ed unknown delivery_tag %s',
-                    $delivery_tag
-                )
-            );
+                'Server nack\'ed unknown delivery_tag %s',
+                $delivery_tag
+            ));
         }
 
         $this->internal_ack_handler($delivery_tag, $multiple, $this->nack_handler);
     }
 
-
-
     /**
      * Handles the deletion of messages from this->publishedMessages and dispatches them to the $handler
      *
-     * @param $delivery_tag
-     * @param $multiple
+     * @param string $delivery_tag
+     * @param bool $multiple
      * @param $handler
      */
     protected function internal_ack_handler($delivery_tag, $multiple, $handler)
@@ -888,14 +804,17 @@ class AMQPChannel extends AbstractChannel
         }
     }
 
-
-
+    /**
+     * @param array $array
+     * @param $value
+     * @return mixed
+     */
     protected function get_keys_less_or_equal(array $array, $value)
     {
         $keys = array_reduce(
             array_keys($array),
             function ($keys, $key) use ($value) {
-                if (bccomp($key, $value) <= 0) {
+                if (bccomp($key, $value, 0) <= 0) {
                     $keys[] = $key;
                 }
 
@@ -907,10 +826,12 @@ class AMQPChannel extends AbstractChannel
         return $keys;
     }
 
-
-
     /**
-     * reject one or several received messages.
+     * Rejects one or several received messages
+     *
+     * @param string $delivery_tag
+     * @param bool $multiple
+     * @param bool $requeue
      */
     public function basic_nack($delivery_tag, $multiple = false, $requeue = false)
     {
@@ -918,10 +839,9 @@ class AMQPChannel extends AbstractChannel
         $this->send_method_frame(array($class_id, $method_id), $args);
     }
 
-
-
     /**
-     * end a queue consumer
+     * Ends a queue consumer
+     *
      * @param string $consumer_tag
      * @param bool $nowait
      * @return mixed
@@ -936,8 +856,6 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
      * @param AMQPReader $args
      * @throws \PhpAmqpLib\Exception\AMQPBasicCancelException
@@ -949,10 +867,8 @@ class AMQPChannel extends AbstractChannel
         throw new AMQPBasicCancelException($consumerTag);
     }
 
-
-
     /**
-     * confirm a cancelled consumer
+     * Confirm a cancelled consumer
      *
      * @param AMQPReader $args
      */
@@ -962,24 +878,23 @@ class AMQPChannel extends AbstractChannel
         unset($this->callbacks[$consumer_tag]);
     }
 
-
-
     /**
-     * start a queue consumer
+     * Starts a queue consumer
+     *
      * @param string $queue
      * @param string $consumer_tag
      * @param bool $no_local
      * @param bool $no_ack
      * @param bool $exclusive
      * @param bool $nowait
-     * @param null $callback
-     * @param null $ticket
+     * @param callback|null $callback
+     * @param int|null $ticket
      * @param array $arguments
-     * @return mixed
+     * @return mixed|string
      */
     public function basic_consume(
-        $queue = "",
-        $consumer_tag = "",
+        $queue = '',
+        $consumer_tag = '',
         $no_local = false,
         $no_ack = false,
         $exclusive = false,
@@ -1013,10 +928,8 @@ class AMQPChannel extends AbstractChannel
         return $consumer_tag;
     }
 
-
-
     /**
-     * confirm a new consumer
+     * Confirms a new consumer
      *
      * @param AMQPReader $args
      * @return string
@@ -1026,10 +939,9 @@ class AMQPChannel extends AbstractChannel
         return $args->read_shortstr();
     }
 
-
-
     /**
-     * notify the client of a consumer message
+     * Notifies the client of a consumer message
+     *
      * @param AMQPReader $args
      * @param AMQPMessage $msg
      */
@@ -1042,12 +954,12 @@ class AMQPChannel extends AbstractChannel
         $routing_key = $args->read_shortstr();
 
         $msg->delivery_info = array(
-            "channel" => $this,
-            "consumer_tag" => $consumer_tag,
-            "delivery_tag" => $delivery_tag,
-            "redelivered" => $redelivered,
-            "exchange" => $exchange,
-            "routing_key" => $routing_key
+            'channel' => $this,
+            'consumer_tag' => $consumer_tag,
+            'delivery_tag' => $delivery_tag,
+            'redelivered' => $redelivered,
+            'exchange' => $exchange,
+            'routing_key' => $routing_key
         );
 
         if (isset($this->callbacks[$consumer_tag])) {
@@ -1061,17 +973,15 @@ class AMQPChannel extends AbstractChannel
         }
     }
 
-
-
     /**
-     * direct access to a queue
-     * if no message was available in the queue, return null
+     * Direct access to a queue if no message was available in the queue, return null
+     *
      * @param string $queue
      * @param bool $no_ack
      * @param null $ticket
-     * @return null|AMQPMessage
+     * @return mixed
      */
-    public function basic_get($queue = "", $no_ack = false, $ticket = null)
+    public function basic_get($queue = '', $no_ack = false, $ticket = null)
     {
         $ticket = $this->getTicket($ticket);
         list($class_id, $method_id, $args) = $this->protocolWriter->basicGet($ticket, $queue, $no_ack);
@@ -1084,10 +994,8 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * indicate no messages available
+     * Indicates no messages available
      *
      * @param AMQPReader $args
      */
@@ -1096,10 +1004,8 @@ class AMQPChannel extends AbstractChannel
         $cluster_id = $args->read_shortstr();
     }
 
-
-
     /**
-     * provide client with a message
+     * Provides client with a message
      *
      * @param AMQPReader $args
      * @param AMQPMessage $msg
@@ -1114,21 +1020,34 @@ class AMQPChannel extends AbstractChannel
         $message_count = $args->read_long();
 
         $msg->delivery_info = array(
-            "delivery_tag" => $delivery_tag,
-            "redelivered" => $redelivered,
-            "exchange" => $exchange,
-            "routing_key" => $routing_key,
-            "message_count" => $message_count
+            'delivery_tag' => $delivery_tag,
+            'redelivered' => $redelivered,
+            'exchange' => $exchange,
+            'routing_key' => $routing_key,
+            'message_count' => $message_count
         );
 
         return $msg;
     }
 
-
-
+    /**
+     * @param string $exchange
+     * @param string $routing_key
+     * @param $mandatory
+     * @param $immediate
+     * @param $ticket
+     * @return mixed
+     */
     private function pre_publish($exchange, $routing_key, $mandatory, $immediate, $ticket)
     {
-        $cache_key = "$exchange|$routing_key|$mandatory|$immediate|$ticket";
+        $cache_key = sprintf(
+            '%s|%s|%s|%s|%s',
+            $exchange,
+            $routing_key,
+            $mandatory,
+            $immediate,
+            $ticket
+        );
         if (false === isset($this->publish_cache[$cache_key])) {
             $ticket = $this->getTicket($ticket);
             list($class_id, $method_id, $args) = $this->protocolWriter->basicPublish(
@@ -1151,10 +1070,8 @@ class AMQPChannel extends AbstractChannel
         return $this->publish_cache[$cache_key];
     }
 
-
-
     /**
-     * publish a message
+     * Publishes a message
      *
      * @param AMQPMessage $msg
      * @param string $exchange
@@ -1165,8 +1082,8 @@ class AMQPChannel extends AbstractChannel
      */
     public function basic_publish(
         $msg,
-        $exchange = "",
-        $routing_key = "",
+        $exchange = '',
+        $routing_key = '',
         $mandatory = false,
         $immediate = false,
         $ticket = null
@@ -1186,12 +1103,10 @@ class AMQPChannel extends AbstractChannel
 
         if ($this->next_delivery_tag > 0) {
             $this->published_messages[$this->next_delivery_tag] = $msg;
-            $this->next_delivery_tag = bcadd($this->next_delivery_tag, '1');
+            $this->next_delivery_tag = bcadd($this->next_delivery_tag, '1', 0);
         }
     }
 
-
-
     /**
      * @param AMQPMessage $msg
      * @param string $exchange
@@ -1202,8 +1117,8 @@ class AMQPChannel extends AbstractChannel
      */
     public function batch_basic_publish(
         $msg,
-        $exchange = "",
-        $routing_key = "",
+        $exchange = '',
+        $routing_key = '',
         $mandatory = false,
         $immediate = false,
         $ticket = null
@@ -1211,22 +1126,26 @@ class AMQPChannel extends AbstractChannel
         $this->batch_messages[] = func_get_args();
     }
 
-
-
+    /**
+     * Publish batch
+     *
+     * @return void
+     */
     public function publish_batch()
     {
         if (empty($this->batch_messages)) {
             return;
         }
 
+        /** @var AMQPWriter $pkt */
         $pkt = new AMQPWriter();
 
         /** @var AMQPMessage $msg */
         foreach ($this->batch_messages as $m) {
             $msg = $m[0];
 
-            $exchange = isset($m[1]) ? $m[1] : "";
-            $routing_key = isset($m[2]) ? $m[2] : "";
+            $exchange = isset($m[1]) ? $m[1] : '';
+            $routing_key = isset($m[2]) ? $m[2] : '';
             $mandatory = isset($m[3]) ? $m[3] : false;
             $immediate = isset($m[4]) ? $m[4] : false;
             $ticket = isset($m[5]) ? $m[5] : null;
@@ -1244,7 +1163,7 @@ class AMQPChannel extends AbstractChannel
 
             if ($this->next_delivery_tag > 0) {
                 $this->published_messages[$this->next_delivery_tag] = $msg;
-                $this->next_delivery_tag = bcadd($this->next_delivery_tag, '1');
+                $this->next_delivery_tag = bcadd($this->next_delivery_tag, '1', 0);
             }
         }
 
@@ -1253,13 +1172,12 @@ class AMQPChannel extends AbstractChannel
         $this->batch_messages = array();
     }
 
-
-
     /**
-     * specify quality of service
-     * @param integer $prefetch_size
-     * @param integer $prefetch_count
-     * @param boolean $a_global
+     * Specifies QoS
+     *
+     * @param int $prefetch_size
+     * @param int $prefetch_count
+     * @param bool $a_global
      * @return mixed
      */
     public function basic_qos($prefetch_size, $prefetch_count, $a_global)
@@ -1277,21 +1195,16 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm the requested qos
-     *
-     * @param AMQPReader $args
+     * Confirms QoS request
      */
     protected function basic_qos_ok($args)
     {
     }
 
-
-
     /**
-     * redeliver unacknowledged messages
+     * Redelivers unacknowledged messages
+     *
      * @param bool $requeue
      * @return mixed
      */
@@ -1305,21 +1218,18 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm the requested recover
-     *
-     * @param AMQPReader $args
+     * Confirm the requested recover
      */
     protected function basic_recover_ok($args)
     {
     }
 
-
-
     /**
-     * reject an incoming message
+     * Rejects an incoming message
+     *
+     * @param string $delivery_tag
+     * @param bool $requeue
      */
     public function basic_reject($delivery_tag, $requeue)
     {
@@ -1327,10 +1237,8 @@ class AMQPChannel extends AbstractChannel
         $this->send_method_frame(array($class_id, $method_id), $args);
     }
 
-
-
     /**
-     * return a failed message
+     * Returns a failed message
      *
      * @param AMQPReader $args
      * @param AMQPMessage $msg
@@ -1352,12 +1260,10 @@ class AMQPChannel extends AbstractChannel
             ));
 
         } elseif ($this->debug) {
-            MiscHelper::debug_msg("Skipping unhandled basic_return message");
+            MiscHelper::debug_msg('Skipping unhandled basic_return message');
         }
     }
 
-
-
     /**
      * @return mixed
      */
@@ -1370,21 +1276,16 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm a successful commit
-     *
-     * @param AMQPReader $args
+     * Confirms a successful commit
      */
     protected function tx_commit_ok($args)
     {
     }
 
-
-
     /**
-     * abandon the current transaction
+     * Rollbacks the current transaction
+     *
      * @return mixed
      */
     public function tx_rollback()
@@ -1396,25 +1297,18 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm a successful rollback
-     *
-     * @param AMQPReader $args
+     * Confirms a successful rollback
      */
     protected function tx_rollback_ok($args)
     {
     }
 
-
-
     /**
-     * Puts the channel into confirm mode. Beware that only non-transactional channels may be put into confirm mode
-     * and vice versa
+     * Puts the channel into confirm mode
+     * Beware that only non-transactional channels may be put into confirm mode and vice versa
      *
-     * @param bool $nowait if nowait is true the method will not wait for an answer of the server
-     *                     and return immediately. defaults to false
+     * @param bool $nowait
      */
     public function confirm_select($nowait = false)
     {
@@ -1423,25 +1317,27 @@ class AMQPChannel extends AbstractChannel
         $this->send_method_frame(array($class_id, $method_id), $args);
 
         if ($nowait) {
-            return NULL;
+            return null;
         }
 
         $this->wait(array($this->waitHelper->get_wait('confirm.select_ok')));
         $this->next_delivery_tag = 1;
     }
 
-
-
+    /**
+     * Confirms a selection
+     *
+     * @return void
+     */
     public function confirm_select_ok()
     {
     }
 
-
-
     /**
-     * Waits for pending acks and nacks from the server. If there are no pending acks, the method returns immediately.
+     * Waits for pending acks and nacks from the server.
+     * If there are no pending acks, the method returns immediately
      *
-     * @param int $timeout If set to value > 0 the method will wait at most $timeout seconds for pending acks.
+     * @param int $timeout Waits until $timeout value is reached
      */
     public function wait_for_pending_acks($timeout = 0)
     {
@@ -1459,10 +1355,31 @@ class AMQPChannel extends AbstractChannel
         }
     }
 
+    /**
+     * Waits for pending acks, nacks and returns from the server. If there are no pending acks, the method returns immediately.
+     *
+     * @param int $timeout If set to value > 0 the method will wait at most $timeout seconds for pending acks.
+     */
+    public function wait_for_pending_acks_returns($timeout = 0)
+    {
+        $functions = array(
+            $this->waitHelper->get_wait('basic.ack'),
+            $this->waitHelper->get_wait('basic.nack'),
+            $this->waitHelper->get_wait('basic.return'),
+        );
 
+        while (count($this->published_messages) !== 0) {
+            if ($timeout > 0) {
+                $this->wait($functions, true, $timeout);
+            } else {
+                $this->wait($functions);
+            }
+        }
+    }
 
     /**
-     * select standard transaction mode
+     * Selects standard transaction mode
+     *
      * @return mixed
      */
     public function tx_select()
@@ -1474,33 +1391,31 @@ class AMQPChannel extends AbstractChannel
         ));
     }
 
-
-
     /**
-     * confirm transaction mode
-     *
-     * @param AMQPReader $args
+     * Confirms transaction mode
      */
     protected function tx_select_ok($args)
     {
     }
 
-
-
+    /**
+     * @param mixed $arguments
+     * @return array|mixed
+     */
     protected function getArguments($arguments)
     {
         return (null === $arguments) ? array() : $arguments;
     }
 
-
-
+    /**
+     * @param mixed $ticket
+     * @return int
+     */
     protected function getTicket($ticket)
     {
         return (null === $ticket) ? $this->default_ticket : $ticket;
     }
 
-
-
     /**
      * Helper method to get a particular method from $this->publishedMessages, removes it from the array and returns it.
      *
@@ -1515,49 +1430,60 @@ class AMQPChannel extends AbstractChannel
         return $message;
     }
 
-
-
     /**
-     * set callback for basic_return
+     * Sets callback for basic_return
+     *
      * @param  callable $callback
      * @throws \InvalidArgumentException if $callback is not callable
      */
     public function set_return_listener($callback)
     {
         if (false === is_callable($callback)) {
-            throw new \InvalidArgumentException("$callback should be callable.");
+            throw new \InvalidArgumentException(sprintf(
+                'Given callback "%s" should be callable. %s type was given.',
+                $callback,
+                gettype($callback)
+            ));
         }
+
         $this->basic_return_callback = $callback;
     }
 
-
-
     /**
      * Sets a handler which called for any message nack'ed by the server, with the AMQPMessage as first argument.
      *
      * @param callable $callback
+     * @throws \InvalidArgumentException
      */
     public function set_nack_handler($callback)
     {
         if (false === is_callable($callback)) {
-            throw new \InvalidArgumentException("$callback should be callable.");
+            throw new \InvalidArgumentException(sprintf(
+                'Given callback "%s" should be callable. %s type was given.',
+                $callback,
+                gettype($callback)
+            ));
         }
+
         $this->nack_handler = $callback;
     }
 
-
-
     /**
      * Sets a handler which called for any message ack'ed by the server, with the AMQPMessage as first argument.
      *
      * @param callable $callback
+     * @throws \InvalidArgumentException
      */
     public function set_ack_handler($callback)
     {
         if (false === is_callable($callback)) {
-            throw new \InvalidArgumentException("$callback should be callable.");
+            throw new \InvalidArgumentException(sprintf(
+                'Given callback "%s" should be callable. %s type was given.',
+                $callback,
+                gettype($callback)
+            ));
         }
+
         $this->ack_handler = $callback;
     }
-
 }
