@@ -1,12 +1,10 @@
 <?php
-
 namespace PhpAmqpLib\Connection;
 
 class AMQPLazyConnection extends AMQPConnection
 {
-
     /**
-     * get socket from current connection
+     * Gets socket from current connection
      *
      * @deprecated
      */
@@ -14,13 +12,11 @@ class AMQPLazyConnection extends AMQPConnection
     {
         $this->connect();
 
-        return $this->sock;
+        return parent::getSocket();
     }
 
-
-
     /**
-     * @inheritdoc
+     * {@inheritdoc}
      */
     public function channel($channel_id = null)
     {
@@ -29,8 +25,6 @@ class AMQPLazyConnection extends AMQPConnection
         return parent::channel($channel_id);
     }
 
-
-
     /**
      * @return null|\PhpAmqpLib\Wire\IO\AbstractIO
      */
@@ -43,15 +37,13 @@ class AMQPLazyConnection extends AMQPConnection
         return $this->io;
     }
 
-
-
     /**
      * Should the connection be attempted during construction?
+     *
      * @return bool
      */
     public function connectOnConstruct()
     {
         return false;
     }
-
 }
