@@ -1,21 +1,27 @@
 <?php
-
 namespace PhpAmqpLib\Connection;
 
 class AMQPSSLConnection extends AMQPStreamConnection
 {
-
+    /**
+     * @param AbstractConnection $host
+     * @param int $port
+     * @param string $user
+     * @param bool $password
+     * @param string $vhost
+     * @param array $ssl_options
+     * @param array $options
+     */
     public function __construct(
         $host,
         $port,
         $user,
         $password,
-        $vhost = "/",
+        $vhost = '/',
         $ssl_options = array(),
         $options = array()
     ) {
         $ssl_context = empty($ssl_options) ? null : $this->create_ssl_context($ssl_options);
-
         parent::__construct(
             $host,
             $port,
@@ -23,9 +29,9 @@ class AMQPSSLConnection extends AMQPStreamConnection
             $password,
             $vhost,
             isset($options['insist']) ? $options['insist'] : false,
-            isset($options['login_method']) ? $options['login_method'] : "AMQPLAIN",
+            isset($options['login_method']) ? $options['login_method'] : 'AMQPLAIN',
             isset($options['login_response']) ? $options['login_response'] : null,
-            isset($options['locale']) ? $options['locale'] : "en_US",
+            isset($options['locale']) ? $options['locale'] : 'en_US',
             isset($options['connection_timeout']) ? $options['connection_timeout'] : 3,
             isset($options['read_write_timeout']) ? $options['read_write_timeout'] : 3,
             $ssl_context,
@@ -34,8 +40,10 @@ class AMQPSSLConnection extends AMQPStreamConnection
         );
     }
 
-
-
+    /**
+     * @param $options
+     * @return resource
+     */
     private function create_ssl_context($options)
     {
         $ssl_context = stream_context_create();
@@ -45,5 +53,4 @@ class AMQPSSLConnection extends AMQPStreamConnection
 
         return $ssl_context;
     }
-
 }
